@@ -11,7 +11,7 @@ use Carp;
   use Moose;
   use Moose::Util::TypeConstraints;
   
-  enum 'FX', [qw(fade)];
+  enum 'FX', [qw(fade chorus delay echo echos flanger overdrive phaser)];
 
   has 'fx' => (
     is => 'rw',
@@ -24,10 +24,6 @@ use Carp;
     my @classparts = split(/::/,ref($self));
     $self->fx(lc($classparts[-1]));
   }
-  
-  sub soxi {
-    return("");
-  }
 }
 
-1;
\ No newline at end of file
+1;
